pub struct RecoveredSsa<P, A> {
pub ssa_id: SsaId<P>,
pub ssa: A,
}Expand description
Contains the already recovered secret scalar corresponding to a specific SSA.
P is the pseudonym type, A is the private key type for SSA.
Fields
ssa_id: SsaId<P>ID of the SSA that was recovered.
ssa: ARecovered secret scalar (private key corresponding to the SSA deposit address).