pub struct SsaPolynomialId<P> {
id: SsaId<P>,
poly_index: PolynomialIndex,
}Expand description
Uniquely identifies a polynomial that allows forming a Session Stealth Address (SSA) corresponding to a specific Session.
The index consists of the following parts:
- The Pseudonym part of the
HoprSenderId- fixed for the given Session. - Index (i) of the Session Stealth Address (SSA)
- Index (j) of the polynomial used to reconstruct the portion of the SSA.
Fields
id: SsaId<P>poly_index: PolynomialIndexImplementations
Sourceimpl<P> SsaPolynomialId<P>
impl<P> SsaPolynomialId<P>
Sourcepub fn new(id: SsaId<P>, poly_index: PolynomialIndex) -> Self
pub fn new(id: SsaId<P>, poly_index: PolynomialIndex) -> Self
Creates a new SsaPolynomialId with the given SsaId and polynomial index.
Sourcepub fn poly_index(&self) -> PolynomialIndex
pub fn poly_index(&self) -> PolynomialIndex
Index (j-value) of the polynomial used to reconstruct the portion of the SSA.